@@ -1,12 +1,12 @@
 ;;; bicep-ts-mode.el --- tree-sitter support for Bicep  -*- lexical-binding: t; -*-
 
-;; Copyright (C) 2023-2023 Free Software Foundation, Inc.
+;; Copyright (C) 2023-2024 Free Software Foundation, Inc.
 
 ;; Author     : Jostein Kjønigsen <jostein@kjonigsen.net>
 ;; Maintainer : Jostein Kjønigsen <jostein@kjonigsen.net>
 ;; Created    : December 2023
 ;; Keywords   : bicep languages tree-sitter
-;; Version    : 0.1.1
+;; Version    : 0.1.2
 ;; X-URL      : https://github.com/josteink/bicep-ts-mode
 
 ;; This file is part of GNU Emacs.
@@ -38,14 +38,17 @@
 (declare-function treesit-node-child "treesit.c")
 (declare-function treesit-node-child-by-field-name "treesit.c")
 
+(defgroup bicep nil
+  "Major-mode for editing Bicep-files"
+  :group 'languages)
+
 (defcustom bicep-ts-mode-indent-offset 2
   "Number of spaces for each indentation step in `bicep-ts-mode'."
-  :version "29.1"
   :type 'natnum
   :safe 'natnump
   :group 'bicep)
 
-(defvar bicep-ts-mode--syntax-table
+(defvar bicep-ts-mode-syntax-table
   (let ((table (make-syntax-table)))
     (modify-syntax-entry ?=  "."   table)
     (modify-syntax-entry ?\' "\""  table)
@@ -65,65 +68,54 @@
   '("var" "param" "resource"
     "module" "type" "metadata"
     "targetScope" "output"
-    "for" "in")
+    "for" "in" "using")
   "Bicep keywords for tree-sitter font-locking.")
 
-(defvar bicep-ts-mode--font-lock-settings
-  (treesit-font-lock-rules
-   :language 'bicep
-   :feature 'comment
-   '((comment) @font-lock-comment-face)
+(setq bicep-ts-mode--font-lock-settings
+      (treesit-font-lock-rules
+       :language 'bicep
+       :feature 'comment
+       '((comment) @font-lock-comment-face)
 
-   :language 'bicep
-   :feature 'delimiter
-   '(("=") @font-lock-delimiter-face)
+       :language 'bicep
+       :feature 'delimiter
+       '(("=") @font-lock-delimiter-face)
 
-   :language 'bicep
-   :feature 'keyword
-   `([,@bicep-ts-mode--keywords] @font-lock-keyword-face)
+       :language 'bicep
+       :feature 'keyword
+       `([,@bicep-ts-mode--keywords] @font-lock-keyword-face)
 
-   :language 'bicep
-   :feature 'definition
-   '((parameter_declaration
-      (identifier) @font-lock-variable-name-face
-      (type) @font-lock-type-face)
-     (variable_declaration
-      (identifier) @font-lock-variable-name-face)
-     (resource_declaration
-      (identifier) @font-lock-variable-name-face)
-     (module_declaration
-      (identifier) @font-lock-variable-name-face)
-     (type_declaration
-      (identifier) @font-lock-type-face)
-     ((builtin_type) @font-lock-type-face)
-     (output_declaration
-      (identifier) @font-lock-variable-name-face)
-     (output_declaration
-      (type) @font-lock-type-face))
+       :language 'bicep
+       :feature 'definition
+       '((type) @font-lock-type-face
+         (parameter_declaration
+          (identifier)) @font-lock-variable-name-face
+         )
 
-   :language 'bicep
-   :feature 'number
-   '((number)
-     @font-lock-number-face)
+       :language 'bicep
+       :feature 'number
+       '((number)
+         @font-lock-number-face)
 
-   :language 'bicep
-   :feature 'string
-   '((string_content) @font-lock-string-face)
+       :language 'bicep
+       :feature 'string
+       '((string_content) @font-lock-string-face)
 
-   :language 'bicep
-   :feature 'boolean
-   '((boolean) @font-lock-constant-face)
+       :language 'bicep
+       :feature 'boolean
+       '((boolean) @font-lock-constant-face)
 
-   :language 'bicep
-   :feature 'functions
-   '((call_expression
-      function: (identifier) @font-lock-function-name-face))
+       :language 'bicep
+       :feature 'functions
+       '((call_expression
+          function: (identifier) @font-lock-function-name-face))
 
-   :language 'bicep
-   :feature 'error
-   :override t
-   '((ERROR) @font-lock-warning-face))
-  "Font-lock settings for BICEP.")
+       :language 'bicep
+       :feature 'error
+       :override t
+       '((ERROR) @font-lock-warning-face))
+      ;;"Font-lock settings for BICEP."
+      )
 
 (defun bicep-ts-mode--defun-name (node)
   "Return the defun name of NODE.
@@ -136,7 +128,6 @@ Return nil if there is no name or if NODE is not a defun node."
 (define-derived-mode bicep-ts-mode prog-mode "Bicep"
   "Major mode for editing BICEP, powered by tree-sitter."
   :group 'bicep-mode
-  :syntax-table bicep-ts-mode--syntax-table
 
   (when (treesit-ready-p 'bicep)
     (treesit-parser-create 'bicep)
@@ -174,10 +165,11 @@ Return nil if there is no name or if NODE is not a defun node."
     (treesit-major-mode-setup)))
 
 ;;;###autoload
-(if (treesit-ready-p 'bicep)
-    (progn
-      (add-to-list 'auto-mode-alist '("\\.bicep\\'" . bicep-ts-mode))
-      (add-to-list 'auto-mode-alist '("\\.bicepparam\\'" . bicep-ts-mode))))
+(and (fboundp 'treesit-ready-p)
+     (treesit-ready-p 'bicep)
+     (progn
+       (add-to-list 'auto-mode-alist '("\\.bicep\\(param\\)?\\'"
+                                       . bicep-ts-mode))))
 
 (provide 'bicep-ts-mode)
 
